@@ -16,7 +16,7 @@ use parent qw( HiPi::Interface );
 use HiPi qw( :max7219 );
 use HiPi::Device::SPI;
 
-our $VERSION ='0.73';
+our $VERSION ='0.74';
 
 __PACKAGE__->create_accessors( qw( ) );
 
@@ -108,6 +108,12 @@ sub send_command {
     return;
 }
 
+sub send_raw_bytes {
+    my($self, @bytes) = @_;
+    $self->device->transfer_byte_array( @bytes );
+    return;
+}
+
 sub set_decode_mode {
     my($self, $mode, $cascade ) = @_;
     # only covers all on or all off
